pub enum LcComponent {
Show 17 variants
Noop,
TwosComplementToSignMagnitude {
size: LcElemSize,
},
TwosComplementToNegaBinary {
size: LcElemSize,
},
DebiasedExponentFractionSign {
size: LcFloatSize,
},
DebiasedExponentSignFraction {
size: LcFloatSize,
},
BitShuffle {
size: LcElemSize,
},
Tuple {
size: LcTupleSize,
},
Delta {
size: LcElemSize,
},
DeltaAsSignMagnitude {
size: LcElemSize,
},
DeltaAsNegaBinary {
size: LcElemSize,
},
Clog {
size: LcElemSize,
},
HClog {
size: LcElemSize,
},
Rare {
size: LcElemSize,
},
Raze {
size: LcElemSize,
},
RunLengthEncoding {
size: LcElemSize,
},
RepetitionRunBitmapEncoding {
size: LcElemSize,
},
ZeroRunBitmapEncoding {
size: LcElemSize,
},
}Expand description
LC component
Variants
Noop
TwosComplementToSignMagnitude
Fields

size: LcElemSizeTwosComplementToNegaBinary
Fields

size: LcElemSizeDebiasedExponentFractionSign
Fields

size: LcFloatSizeDebiasedExponentSignFraction
Fields

size: LcFloatSizeBitShuffle
Fields

size: LcElemSizeTuple
Fields

size: LcTupleSizeDelta
Fields

size: LcElemSizeDeltaAsSignMagnitude
Fields

size: LcElemSizeDeltaAsNegaBinary
Fields

size: LcElemSizeClog
Fields

size: LcElemSizeHClog
Fields

size: LcElemSizeRare
Fields

size: LcElemSizeRaze
Fields

size: LcElemSizeRunLengthEncoding
Fields

size: LcElemSizeRepetitionRunBitmapEncoding
Fields

size: LcElemSizeZeroRunBitmapEncoding
Fields

size: LcElemSizeTrait Implementations
Sourceimpl Clone for LcComponent
impl Clone for LcComponent
Sourcefn clone(&self) -> LcComponent
fn clone(&self) -> LcComponent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LcComponent
impl Debug for LcComponent
Sourceimpl<'de> Deserialize<'de> for LcComponent
impl<'de> Deserialize<'de> for LcComponent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for LcComponent
impl Hash for LcComponent
Sourceimpl JsonSchema for LcComponent
impl JsonSchema for LcComponent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for LcComponent
impl Ord for LcComponent
Sourcefn cmp(&self, other: &LcComponent) -> Ordering
fn cmp(&self, other: &LcComponent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LcComponent
impl PartialEq for LcComponent
Sourceimpl PartialOrd for LcComponent
impl PartialOrd for LcComponent
Sourceimpl Serialize for LcComponent
impl Serialize for LcComponent
impl Copy for LcComponent
impl Eq for LcComponent
impl StructuralPartialEq for LcComponent