pub fn decompress(
preprocessors: &[LcPreprocessor],
components: &[LcComponent],
encoded: &[u8],
) -> Result<AnyArray, LcCodecError>Expand description
Decompress the encoded data into an array using LC.
Errors
Errors with
LcCodecError::HeaderDecodeFailedif decoding the header failedLcCodecError::DecodeDataLengthMismatchif decoding produced a different number of bytes than expectedLcCodecError::LcDecodeFailedif an opaque decoding error occurred